@@ -102,7 +102,7 @@ def city_parse(args):
     # ValueError-unable to decode json, UnboundLocalError-used var before declaring
     except (ValueError,UnboundLocalError) as err:
         print("Invalid city")
-        print("Please use format ex: $ cli-weather bengaluru [-c country_name][-a][-u M/S/F][-d]")
+        print("Please use format ex: $ cli-weather bengaluru [-c country_name][-a][-u M/S/I][-d]")
         return
 
     # defalut metric values
